@@ -7,6 +7,10 @@ READ_CHARACTERISTIC = "bd4ac612-0b45-11e3-8ffd-0800200c9a66"
 SECURE_WRITE_CHARACTERISTIC = "bd4ac613-0b45-11e3-8ffd-0800200c9a66"
 SECURE_READ_CHARACTERISTIC = "bd4ac614-0b45-11e3-8ffd-0800200c9a66"
 
+APPLE_MFR_ID = 76
+YALE_MFR_ID = 465
+HAP_FIRST_BYTE = 0x06
+
 
 class Commands(Enum):
 
